<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation>Eraro en config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation>Eraro en la kromprograma lanĉo:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation>La dosiero ne povas ŝarĝiĝi.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation>Tiu dosierformo estas nevalida.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation>La dosiero ne povas konserviĝi.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation>La XML ne povas sintakse analiziĝi.</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation>Tiu kodoprezento estas nerekonita.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation>Respondo estas manka ĉe la linio:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation>La datumbazo ne povas ŝarĝebliĝi.
Mnemozino nun kreas tmp-dosieron.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemozino</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Akcepti</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation>La dosiero ekzistas:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation>&amp;Anstataŭigi</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Rezigni</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation>Duobloj forviŝiĝis: </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation>Ekzistas kartoj kun malsamaj respondoj al jena demando:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Kunfandi kaj redakti</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation>&amp;Ne kunfandi</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation>Farita!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="unfinished">Vi ne jam scias la respondon al ĉi tiu karto.</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="unfinished">Simila al 0, sed vi plikonadas ĝin.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="unfinished">Montru ĝin pli malofte.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="unfinished">Nun vi scias tiun karton,</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="unfinished">kaj probable vi memoros ĝin dum kelkaj tagoj.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="unfinished">Vi tute forgesis ĉi tiun karton.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="unfinished">Via apenaŭ memoris la respondon; la intertempo estis multe tro longa.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="unfinished">Vi memoris la ĝustan respondon, sed per multa peno.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="unfinished">La intertempo probable estis tro longa.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="unfinished">Vi memoris la ĝustan respondo per iom da peno.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="unfinished">La intertempo probable estis ĝusta.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="unfinished">Vi sciis la ĝustan respondon, sed sen ia</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="unfinished"> malfacilo. La intertempo probable estis tro mallonga.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemozino</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>Ĉefa aŭtoro: Peter BIENSTMAN

</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation>Pli da informaĵo ekzistas ĉe http://mnemosyne-proj.org.
</translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>Pri</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>Aktivigi kategoriojn</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>Elektu la kategoriojn, kiujn vi volas aktivigi:</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>Aktivigi neniujn</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>Aktivigi ĉiujn</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Akcepti</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Rezigni</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>Defaŭlto</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemozino</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>Ĉu vi ja volas forigi tiun karton?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Jes</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Ne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Demando:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respondo:</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>Skribata formo:</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>Traduko:</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>Tiu karto jam estas en la datumbazo.
</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>La duoblo ne aldoniĝis.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Akcepti</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>Ekzistas malsamaj respondoj por</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation> jena demando:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Kunfandi kaj redakti</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>&amp;Aldoni, kiel jam estas</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>&amp;Ne aldoni</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>Aldoni kartojn</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategorio:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Demando:</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>Elparolo:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respondo:</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>Ankaŭ &amp;malon aldoni</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>Elektu komencan rangon:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Stir+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>Aŭ vi ne jam scias ĉi tiun karton, aŭ vi forgesis ĝin.</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Stir+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>Simila al 0, sed vi plikonadas ĝin.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Stir+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>Nun vi scias tiun karton, kaj probable vi memoros ĝin dum kelkaj tagoj.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Stir+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>Vi memoris la ĝustan respondon, sed kun multa peno. La intertempo probable estis tro longa.</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Stir+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>Vi memoris la ĝustan respondo per iom da peno. La intertempo probable estis ĝusta.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Stir+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>Vi sciis la ĝustan respondon, sed sen ia malfacilo. La intertempo probable estis tro mallonga.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>Tajpu la demandon kaj la respondon, kaj poste elektu komencan rangon.</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Antaŭmontri</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Stir+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Fini</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>Ŝanĝi kategorion</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategorio:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Akcepti</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Rezigni</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>Mnemozina agordo</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>Ŝvebu per la muso super la butonoj por legi pli da informaĵo.</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Apero</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>Elekti la demandan kaj respondan tiparon</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>Elekti la tiparon por unuopaj demandoj kaj respondoj</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>Elekti la listan tiparon</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>Elekti la tiparon por la listo de ĉioj en la kartaro</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>Pligrandigi mallatinajn signojn po</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>Kelkfoje malsimplaj signoj estas apenaŭ legeblaj, kiam ili estas tro malgrandaj.</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>gradoj</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>Protokola alŝutado</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Alŝuti anonimajn protokolojn</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>Disdoni anonimajn statistikojn por kontribui al la esplorado pri la memoro</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>Trakto pri duoblojn</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>Serĉi duoblojn dum aldoni novajn kartojn</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>Permesi duoblojn en malsamaj kategorioj</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>Ripetada procedo</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation>Nombro da 0-rangaj kartoj por teni en la mano:</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>(Jen né estas la nombro da 0-rangaj kartoj, kiun vi volas ekmemori en unu tago.)</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation>Lerni novajn kartojn en hazarda ordo.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Akcepti</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Defaŭltoj</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Rezigni</translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>Redakti la karton</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategorio:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Demando:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respondo:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Akcepti</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Antaŭmontri</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Stir+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Rezigni</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>Bonvolu atendi . . .</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Redakti</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Stir+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Antaŭmontri</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Stir+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>&amp;Aldoni malojn</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>Vidi s&amp;tatistikojn</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Stir+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Forviŝi</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>&amp;Ŝanĝi kategorion</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>&amp;Aldoni malojn</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>Ĉu vi volas aldoni la malojn de tiuj kartoj?</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>Ĉu vi volas aldoni la malo de tiu karto?</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemozino</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>

La proceso kreos duoblojn, se la maloj </translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>jam ekzistas; 
vi devus forigi duoblojn</translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>poste.</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Jes</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Ne</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Rango:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Facileco:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Ripetoj:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Eraroj:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Tagoj post lasta ripeto:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Tagoj antaŭ sekva ripeto:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Akcepti</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>Ĉu vi volas forviŝi tiujn kartojn?</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>Ĉu vi volas forviŝi tiun karton?</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>La tekston, kiun vi tajpis, ne ekzistas.</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>&amp;Retrovi</translation>
    </message>
    <message>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Trovi</translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>Respondo</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorio</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Redakti la kartaron</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Trovi</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation>Alt+F</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>Por redakti la karton dekstre alklaku ĝin.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Fini</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>Ĉiujn dosierojn (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Elporti</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>Elporti al dosiero</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Dosierformo:</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>Elportu ĉi tien:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Foliumi</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>Elportu ĉi tiujn kategoriojn:</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>&amp;Elekti ĉiujn</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>Forigi la lernajn datumojn en la elportita dosiero</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Akcepti</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Rezigni</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>Defaŭlto</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>Ĉiujn dosierojn (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Enporti</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>Enporti el dosiero</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Dosierformo:</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>Enportu el ĉi tiu dosiero:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Foliumi</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>Metu senkategoriajn kartojn en ĉi tiun kategorion:</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>(Ĉiuj kartoj aldoniĝos en la nunan datumbazon.)</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>Forigi la lernajn datumojn en la enportita dosiero</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Akcepti</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Rezigni</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation type="unfinished">Mnemozinaj datumbazoj (*.mem)</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">Novan</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation type="unfinished">Bonvolu atendi . . .</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">Mnemozino</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation type="unfinished">Ĉu vi volas forviŝi tiun karton?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished">&amp;Jes</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished">&amp;Ne</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation type="unfinished">Ĉi tiu karto reaperos post </translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation type="unfinished"> tagoj.</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation type="unfinished">Sekva ripeto: hodiaŭ</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation type="unfinished">Sekva ripeto: morgau</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation type="unfinished">Sekva ripetado post </translation>
    </message>
    <message>
        <source> days.</source>
        <translation type="unfinished"> tagoj</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation type="unfinished">Demando:</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation type="unfinished">Defaŭlto</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished">Vidi respondon</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation type="unfinished">Antaŭlerni</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation type="unfinished">Elekti tagojn antaŭ la sekva ripeto:</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation type="unfinished">Rangigi vian respondon:</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation type="unfinished">Planataj: </translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation type="unfinished">Nekonataj: </translation>
    </message>
    <message>
        <source>All: </source>
        <translation type="unfinished">Ĉiuj: </translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemozino</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Demando:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respondo:</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>Vidi respondon</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Rangigi vian respondon:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Stir+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Malfermi . . .</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Stir+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Konservi</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Stir+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Konservi &amp;kiel . . .</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Fini</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Pri</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Pri</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>Aldoni kartojn</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>&amp;Aldoni kartojn</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Stir+A</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>Aktivigi kate&amp;goriojn</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Stir+G</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Redakti la kartaron</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>Redakti la &amp;kartaron</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Stir+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Enporti</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>E&amp;lporti</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>Vidi &amp;ilobreton</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>Redakti nunan karton</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>&amp;Redakti nunan karton</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Stir+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>Forviŝi nunan karton</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>&amp;Forviŝi nunan karton</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>For</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>Forigi &amp;duoblojn</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>&amp;Agordi Mnemozinon</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>Kiel ekuzi</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>&amp;Kiel ekuzi</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>Malsupren</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enigklavo</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Enenklavo</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Spacetklavo</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Stir+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>Vidi statistikojn</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>Vidi s&amp;tatistikojn</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Stir+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>Konsileto de la tago</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>&amp;Konsileto de la tago</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>Ĉefa ilobreto (Mnemozino)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Dosiero</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>&amp;Kartaro</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Agordoj</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Helpo</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>Defaŭlto</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Demando:</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>Antaŭmontri karton</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Demando:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respondo:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Akcepti</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>&amp;Kiel ekuzi</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>Saluton!

Mi estas Mnemozinospeco de papilio, kiu havas la saman nomon, kiel la greka diino de memoro.

Mi povas helpi vin koni kaj memori la respondojn al demandoj ŝpare: kun mi vi pripensos la kartoj, pri kiuj vi forgesemas. Vi ne malŝpari vian tempon pri tio, kion vi scias bone.

Do mi decidos, kiam mi devus montri al vi la demandojn; kaj vi devos rangigi vian respondojn al la demandoj.

Nuntempe rigardu ni la signifojn de tiuj rangoj.</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>Enkonduko</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>Rangoj estas el 0 ĝis 5.

Oni uzas rangojn 0 kaj 1, se oni ne jam scias la respondon, aŭ se oni forgesis ĝin. Karton kun grado 1 oni pli ekkonadas ol karton kun grado 0, kaj mi ripetos ĝin pli malofte.

Mi demandados ĉi tiujn demandojn, ĝis ke vi asignos al ilin rangon 2 aŭ pli altan rangon (la ĝusta rango ne gravas). Rango 2 signifas, ke vi pensas, ke vi povos memori la karton dum almenaŭ unu aŭ du tagoj. La dua rango estas la transiro inter longtempa memoro kaj mallongtempa memoro.

Mi planos ĉi tiun karton por la tempo, kiam mi pensos, ke vi povas memori la respondon per iu peno, sed ne post vi tute forgesos ĝin. Ĉi tiu estas la plej ŝpara metodo de lerno.</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>Rangoj 0-2</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>Se mi tro baldaŭ demandi, kaj vi povas memori la respondon tute senpene, rangigu la karton 5. Tiam mi atendos pli longtempe, antaŭ mi remontri al vi ĉi tiun demandon.

Se mi montros la karton ĉe la ĝusta tempo, por ke vi memoras la respondon kun iom da peno, uzu la rangon 4.

Se anstataŭe vi memoros la respondon tro pene, kaj vi pensos, ke mi atendis tro longtempe, antaŭ mi demandis la karton, uzu la rangon 3.

Se vi tute ne memoros la respondon, rangigu ĝin aŭ 0 aŭ 1; mi demandados la karton, ĝis ke vi pensos, ke vi povas memori ĝin dum kelkaj tagoj.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>Rangoj 3-5</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>Se vi estas statistikema, mi povas konservi detalajn protokolojn de viaj pliboniĝado.

Ne tion solan mi povas fari: se vi volas, mi alŝutados senpercepte tute anoniman version de tiuj protokoloj al centra retejo por analizo; tiel mi plibonigos min. Vi ankaŭ tiel kontribuos al scienca esploro pri longtempa memoro.

Malŝaltu jenan markobutonon, se vi ne volas, ke mi faros tion.</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Alŝuti anonimajn protokolojn</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>(Vi ĉiam povas ŝanĝi ĉi tiun agordon per la “Agordi Mnemozinon” menuopcio.)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistikoj</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation>Nun vi povas ekuzi min!
&lt;p&gt;
Aldonu novajn kartojn per la “plus” bildsimbolo ĉe la supromaldekstro de la fenestro.
&lt;p&gt;
Memoru: vi ne povas konservi vian laboron. Mi mem faros tion.
&lt;p&gt;
Se vi volas havi la plej bonajn rezultojn, uzu min ĉiutage. Mi penos tamen fari bone, eĉ se vi prokrastos aŭ antaŭlernos.
&lt;p&gt;
Se vi volas vidi pli da dokumentado, iru al http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Feliĉan lernadon!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>Ek!</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>Enmeti &amp;bildon</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Stir+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>Enmeti &amp;sonon</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Stir+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>Aldoni &amp;tri-flankajn kartojn</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Bildaj dosieroj</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Enmeti bildon</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>Sonaj dosieroj</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>Enmeti sonon</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for next week: </source>
        <translation type="obsolete">Planataj kartoj por la sekva semajno: </translation>
    </message>
    <message>
        <source>In</source>
        <translation>Post</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>tagoj:</translation>
    </message>
    <message>
        <source>Number of cards with the following grades: </source>
        <translation type="obsolete">Nombro da kartoj kun tiujn rangojn: </translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>Rango</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation>Neniu nuna karto.</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Rango:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Facileco:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Ripetoj:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Eraroj:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Tagoj post la lasta ripeto:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Tagoj antaŭ la sekva ripeto:</translation>
    </message>
    <message>
        <source>Scheduled cards for next week:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>Kategorio</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>Kartoj</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistikoj</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>Plano</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>Rangoj</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorioj</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation>Nuna karto</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Akcept</translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>Se vi volas havi la plej bonajn rezultojn, ripetadu ĉiutage.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>Se vi forestis dum kelkaj tagoj, ne zorgas. Laboru tiom, kiom vi volas; la kartoj, kiun vi ne volas respondi, replaniĝos aŭtomate.</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>La “Nombro da 0-rangaj kartoj por teni en la mano” agordo decidas kiom da novaj kartoj vi penos lerni samtempe. Ĝi &lt;b&gt;ne&lt;/b&gt; decidas kiom da kartoj vi devus lerni en unu tago. Ví devas juĝi tion: vi povas lerni pli kartojn aŭ malpli kartojn, dependante je via stato.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>Mallonge, penu ripetadi ĉiutage; sed ne tro zorgu pri malpligrandigadi la “Planataj” nombrilon ĝis nul, kaj certe ne pri malpligrandigadi la “Nekonataj” nombrilon ĝis nul.</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>Kartoj 1-rangaj estas malsamaj, kiel 0-rangaj: ili aperas pli malofte, kaj ili ne influas la “Nombro da 0-rangaj kartoj por teni en la mano” agordon.</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>Vi ankaŭ povas uzi la klavaron. La eniga klavo kaj la spaceta klavo efektivigi la defaŭltan faron (“Vidi respondon” aŭ la rango 4). Numerkavojn oni ankaŭ povas uzi.</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>Vi povas elekti la kategoriojn, kiujn vi volas studi, per la “Aktivigi kategoriojn” menuagordo.</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>Estas rekomendate, ke vi metas ĉiujn viajn kartojn en unu datumbazo kaj uzas kategoriojn por organizi ilin. Uzi “Aktivigi kategoriojn” estas ege pli oportune ol ŝalti kaj malŝalti multajn diversajn datumbazojn.</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>Vi povas enporti kartojn el multaj dosierformoj: XML dosieroj, tab-limigitaj TXT dosieroj ktp.</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>Se vi havas kartojn en Word aŭ Excel, elportu ilin al tab-limigitaj TXT dosieroj kun la UTF-8 kodoprezento; tiam vi povos porti ilin en Mnemozinon.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>Se vi volas presi viajn kartojn, elportu ilin al TXT dosiero; tion vi povos presi per via plej ŝatata verkilo.</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>Vi povas havigi iun alian viajn kartojn per elporti ilin al XML post elekti la “Forigi la lernajn datumojn en la elportita dosiero” agordon.</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>Se vi studas alilandan ligvon, kiu uzas skribmetodon, kiun vi ne bone scias, la defaŭlta tipara grando estas kelkfoje tro malgranda. Se vi volas pligrandigi tiujn signojn sed ne anglan tekston, uzu la “Pligrandigi mallatinajn signojn po . . . gradoj” agordon.</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>Vi ja povas aldoni bildojn kaj sonojn en viajn kartojn! Dekstre alklaku la demandan aŭ respondan tajpujon, kiam vi redaktas karton; poste elektas la ĝustan butonon el la menuo, kiu aperas.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>Estas rekomendate, ke vi konservas viajn sonajn kaj bildajn dosierojn en vian “.mnemosyne” dosierujon. Tiel estas pli facile transigi viajn datumojn inter diversajn komputilojn.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>Kiam vi aldonas tri-flankajn kartojn, du normalajn kartojn estas kreitaj. Unu havas la skribatan formon, kiel la demandon, kaj la elparolon kaj tradukon, kiel la respondon; la alia havas la tradukon, kiel la demandon, kaj la skribatan formon kaj elparolon, kiel la respondon.</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>Vi ja povas uzi bazajn etikedojn de HTML en viaj kartoj por kontroli ilian aspekton.</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>Mnemozino povas uzi LaTeX por vidigi matematikajn formulojn, ekz. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (Por tion LaTeX kaj dvipng devas esti instalitaj.)</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>La plej bona metodo por enarkivigi viajn datumojn estas kopii vian “.mnemosyne” dosierujon (se vi metas ĉiujn viajn dosierojn tie, kiel estas rekomendate) kaj movi ĝin en alian diskingon. Mnemozino ja aŭtomate konservas enarkivigojn uzante XML en “.mnemosyne/backups”—sed tio ne helpus ĝin, se via durdisko rompiĝus!</translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>Vi povas uzi Mnemozinon sole per poŝmemorilo. Kopiu “C:\Program Files\Mnemosyne” al via poŝmemorilo, kaj poste kopiu la “.mnemosyne” dosierujon el via hejmdosierujo en la “Mnemosyne” dosierujon de la poŝmemorilo.</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>Se vi volas uzi Mnemozinon ĉe diversajn komputilojn, ekzistas oportuna ilo nomata Unison por helpi vin sinkronigi viajn datumojn. Iru al la Mnemozina retpaĝaro por plua informaĵo.</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>Vi povas ordigi la kartojn en la “Redakti la karton” dialogujo laŭ respondo aŭ laŭ kategorio per alklaki la ĝustan kolumnan titolon. Reklakado ŝanĝas la ordon (kreske aŭ malkreske).</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>Se vi volas pli precizan kontrolon pri la konduto de LaTeX, vidu la klarigon de la &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; etikedoj ĉe la Mnemozina retpaĝaro.</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>Progresemaj uzantoj povas plu akomodi Mnemozinon per redakti la “config.py” dosieron en la “.mnemosyne” dosierujo. Oni ankaŭ povas instali kromprogramojn por tajlori Mnemozinon eĉ plu.</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>Konsileto de la tago</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ĉu vi sciis...?&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>&amp;Vidi konsiletojn dum lanĉo</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Laste</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Sekve</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermu</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
</TS>
